@@ -91,10 +91,14 @@ def hashivault_write(params):
             else:
                 write_data  = {}
             write_data.update(data)
-            client.write((secret), **write_data)
+            returned_data = client.write((secret), **write_data)
+            if returned_data:
+                result['data'] = returned_data
             result['msg'] = "Secret %s updated" % secret
         else:
-            client.write((secret), **data)
+            returned_data = client.write((secret), **data)
+            if returned_data:
+                result['data'] = returned_data
             result['msg'] = "Secret %s written" % secret
     result['changed'] = True
     return result
